@@ -26,7 +26,6 @@
 #include "akregator_part.h"
 #include "akregator_debug.h"
 
-#include "config-akregator.h"
 #include "messageviewer/messageviewersettings.h"
 #include "akregatorconfig.h"
 #include "aboutdata.h"
@@ -123,7 +122,7 @@ static QDomDocument createDefaultFeedList()
 
     QDomElement planetkde = doc.createElement(QStringLiteral("outline"));
     planetkde.setAttribute(QStringLiteral("text"), i18n("Planet KDE"));
-    planetkde.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("http://planetkde.org/rss20.xml"));
+    planetkde.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("https://planetkde.org/rss20.xml"));
     mainFolder.appendChild(planetkde);
 
     QDomElement apps = doc.createElement(QStringLiteral("outline"));
@@ -138,7 +137,7 @@ static QDomDocument createDefaultFeedList()
 
     QDomElement portugueuseKde = doc.createElement(QStringLiteral("outline"));
     portugueuseKde.setAttribute(QStringLiteral("text"), i18n("Planet KDE Brazilian Portuguese"));
-    portugueuseKde.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("http://planetkde.org/pt-br/rss20.xml"));
+    portugueuseKde.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("https://planetkde.org/pt-br/rss20.xml"));
     portugueuseFolder.appendChild(portugueuseKde);
 
     // spanish feed(s)
@@ -148,7 +147,7 @@ static QDomDocument createDefaultFeedList()
 
     QDomElement spanishKde = doc.createElement(QStringLiteral("outline"));
     spanishKde.setAttribute(QStringLiteral("text"), i18n("Planet KDE España"));
-    spanishKde.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("http://planet.kde-espana.org/atom.xml"));
+    spanishKde.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("https://planet.kde-espana.org/atom.xml"));
     spanishFolder.appendChild(spanishKde);
 
     return doc;
@@ -199,7 +198,6 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Akregator"), this);
 
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/akregator/data/");
-    qDebug() <<"path *****************************************************"<<path;
     QDir().mkpath(path);
     m_standardFeedList = path + QStringLiteral("/feeds.opml");
 
@@ -655,10 +653,12 @@ void Part::showOptions()
 
     if (!m_dialog) {
         m_dialog = new KCMultiDialog(m_mainWidget);
-        connect(m_dialog, SIGNAL(configCommitted()),
-                this, SLOT(slotSettingsChanged()));
-        connect(m_dialog, SIGNAL(configCommitted()),
-                TrayIcon::getInstance(), SLOT(settingsChanged()));
+        connect(m_dialog, QOverload<>::of(&KCMultiDialog::configCommitted),
+                this, &Part::slotSettingsChanged);
+        if (TrayIcon::getInstance()) {
+            connect(m_dialog, QOverload<>::of(&KCMultiDialog::configCommitted),
+                    TrayIcon::getInstance(), &TrayIcon::settingsChanged);
+        }
 
         m_dialog->addModule(QStringLiteral("akregator_config_general"));
         m_dialog->addModule(QStringLiteral("akregator_config_appearance"));
