@@ -28,13 +28,8 @@
 #include "treenodevisitor.h"
 #include "utils.h"
 
-#include <KLocalizedString>
-
-#include <QApplication>
 #include <QPaintDevice>
-#include <QPalette>
 #include <QString>
-#include <KFormat>
 using namespace Akregator;
 
 DefaultCombinedViewFormatter::DefaultCombinedViewFormatter(const QString &grantleeDirectory, const QUrl &imageDir, QPaintDevice *device)
