@@ -27,6 +27,7 @@
 #include "abstractselectioncontroller.h"
 
 #include <QPointer>
+#include <QAbstractItemModel>
 
 class QModelIndex;
 class QPoint;
@@ -35,6 +36,7 @@ class KJob;
 
 namespace Akregator {
 class ArticleListJob;
+class FilterUnreadProxyModel;
 
 class SelectionController : public AbstractSelectionController
 {
@@ -74,6 +76,9 @@ public:
 
 public Q_SLOTS:
 
+    //impl
+    void settingsChanged() override;
+
     //impl
     void setFilters(const std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher> > &) override;
 
@@ -82,6 +87,7 @@ public Q_SLOTS:
 
 private Q_SLOTS:
 
+    void subscriptionDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void selectedSubscriptionChanged(const QModelIndex &index);
     void articleSelectionChanged();
     void articleIndexDoubleClicked(const QModelIndex &index);
@@ -90,13 +96,16 @@ private Q_SLOTS:
 
 private:
 
+    void setCurrentSubscriptionModel();
+
     QSharedPointer<FeedList> m_feedList;
     QPointer<QAbstractItemView> m_feedSelector;
-    Akregator::ArticleLister *m_articleLister;
-    Akregator::SingleArticleDisplay *m_singleDisplay;
-    Akregator::SubscriptionListModel *m_subscriptionModel;
-    Akregator::FolderExpansionHandler *m_folderExpansionHandler;
-    Akregator::ArticleModel *m_articleModel;
+    Akregator::ArticleLister *m_articleLister = nullptr;
+    Akregator::SingleArticleDisplay *m_singleDisplay = nullptr;
+    Akregator::FilterUnreadProxyModel *m_subscriptionModel = nullptr;
+    QAbstractItemModel *m_currentModel = nullptr;
+    Akregator::FolderExpansionHandler *m_folderExpansionHandler = nullptr;
+    Akregator::ArticleModel *m_articleModel = nullptr;
     QPointer<TreeNode> m_selectedSubscription;
     QPointer<ArticleListJob> m_listJob;
 };
