@@ -39,12 +39,11 @@ public:
 Q_SIGNALS:
     void restoreSession(Akregator::CrashWidget::CrashAction type);
 
-private Q_SLOTS:
+private:
     void slotRestoreSession(Akregator::CrashWidget::CrashAction type);
 
-private:
-    Akregator::CrashWidget *mCrashWidget;
-    Akregator::MainWidget *mMainWidget;
+    Akregator::CrashWidget *mCrashWidget = nullptr;
+    Akregator::MainWidget *mMainWidget = nullptr;
 };
 }
 #endif // AKREGATORCENTRALWIDGET_H
